==> echobase-ui-2.1-sources.jar: fr/ifremer/echobase/ui/actions/workingDb/Delete.java <==
package fr.ifremer.echobase.ui.actions.workingDb;

/*
 * #%L
 * EchoBase :: UI
 * $Id: Delete.java 591 2012-09-02 16:38:43Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/echobase/tags/echobase-2.1/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/workingDb/Delete.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import fr.ifremer.echobase.entities.WorkingDbConfiguration;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * To delete a selected {@link WorkingDbConfiguration}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.1
 */
public class Delete extends AbstractWorkingDbAction {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log = LogFactory.getLog(Delete.class);

    public String confirmDelete() {

        return SUCCESS;
    }

    @Override
    public String execute() throws Exception {

        String result = INPUT;
        try {
            getService().delete(getConf().getTopiaId());
            addFlashMessage(_("echobase.info.workingDbconfiguration.deleted",
                               conf.getUrl()));

            conf = null;
            result = SUCCESS;
        } catch (Exception e) {
            if (log.isErrorEnabled()) {
                log.error("Could not delete workgingDbconfiguration", e);
            }
        }

        return result;
    }
}

==> echobase-ui-2.2-sources.jar: fr/ifremer/echobase/ui/actions/workingDb/Delete.java <==
package fr.ifremer.echobase.ui.actions.workingDb;

/*
 * #%L
 * EchoBase :: UI
 * $Id: Delete.java 842 2013-08-15 10:53:16Z tchemit $
 * $HeadURL: https://forge.codelutin.com/svn/echobase/tags/echobase-2.2/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/workingDb/Delete.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

import fr.ifremer.echobase.entities.WorkingDbConfiguration;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * To delete a selected {@link WorkingDbConfiguration}.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.1
 */
public class Delete extends AbstractWorkingDbAction {

    private static final long serialVersionUID = 1L;

    /** Logger. */
    private static final Log log = LogFactory.getLog(Delete.class);

    public String confirmDelete() {

        return SUCCESS;
    }

    @Override
    public String execute() throws Exception {

        String result = INPUT;
        try {
            workingDbConfigurationService.delete(getConf().getTopiaId());
            addFlashMessage(_("echobase.info.workingDbconfiguration.deleted",
                               conf.getUrl()));

            conf = null;
            result = SUCCESS;
        } catch (Exception e) {
            if (log.isErrorEnabled()) {
                log.error("Could not delete workgingDbconfiguration", e);
            }
        }

        return result;
    }
}
